@@ -10,12 +10,8 @@ class Permutation(object):
         """
         A constructor of Permutation class which creates a new list and assigns integer
         numbers starting from 0 to given input n.
-
-        Parameters
-        ----------
-         n: int
-            integer input.
-         """
+        :param n: n of permutation n!
+        """
         self.__n = n
         self.__a = []
         for i in range(n):
@@ -24,22 +20,14 @@ class Permutation(object):
     def get(self) -> list:
         """
         The get method returns the list a.
-
-        Returns
-        ----------
-        list
-            a
+        :return: a
         """
         return self.__a
 
     def next(self) -> bool:
         """
-         The next method generates next permutation for the list a.
-
-        Returns
-        ----------
-        boolean
-            true if next permutation is possible, false otherwise.
+        The next method generates next permutation for the list a.
+        :return: true if next permutation is possible, false otherwise.
         """
         i = self.__n - 2
         while i >= 0 and self.__a[i] >= self.__a[i + 1]:
